diff --git a/lms/djangoapps/support/static/support/jsx/logged_out_user.jsx b/lms/djangoapps/support/static/support/jsx/logged_out_user.jsx
index d9b59fbdbe..6cf2294880 100644
--- a/lms/djangoapps/support/static/support/jsx/logged_out_user.jsx
+++ b/lms/djangoapps/support/static/support/jsx/logged_out_user.jsx
@@ -18,26 +18,19 @@ function LoggedOutUser({ platformName, loginQuery, supportEmail }) {
diff --git a/lms/djangoapps/support/tests/test_views.py b/lms/djangoapps/support/tests/test_views.py
index c1aacadbec..a899bc572a 100644
--- a/lms/djangoapps/support/tests/test_views.py
+++ b/lms/djangoapps/support/tests/test_views.py
@@ -65,6 +65,22 @@ class SupportViewManageUserTests(SupportViewTestCase):
super(SupportViewManageUserTests, self).setUp()
SupportStaffRole().add_users(self.user)
+ def test_get_contact_us(self):
+ """
+ Tests Support View contact us Page
+ """
+ url = reverse('support:contact_us')
+ response = self.client.get(url)
+ self.assertEqual(response.status_code, 200)
+
+ def test_get_password_assistance(self):
+ """
+ Tests password assistance
+ """
+ url = '/password_assistance'
+ response = self.client.get(url)
+ self.assertEqual(response.status_code, 200)
+
def test_get_support_form(self):
"""
Tests Support View to return Manage User Form
diff --git a/lms/static/js/student_account/views/AccessView.js b/lms/static/js/student_account/views/AccessView.js
index cb1f50c400..6e2193618e 100644
--- a/lms/static/js/student_account/views/AccessView.js
+++ b/lms/static/js/student_account/views/AccessView.js
@@ -128,7 +128,12 @@
},
loadForm: function(type) {
- var loadFunc = _.bind(this.load[type], this);
+ var loadFunc;
+ if (type === 'reset') {
+ loadFunc = _.bind(this.load.login, this);
+ loadFunc(this.formDescriptions.login);
+ }
+ loadFunc = _.bind(this.load[type], this);
loadFunc(this.formDescriptions[type]);
},
@@ -225,7 +230,7 @@
},
passwordEmailSent: function() {
- var $loginAnchorElement = $('#login-anchor');
+ var $loginAnchorElement = $('#login-form');
this.element.hide($(this.el).find('#password-reset-anchor'));
this.element.show($loginAnchorElement);
this.element.scrollTop($loginAnchorElement);
@@ -236,7 +241,7 @@
category: 'user-engagement'
});
- this.element.hide($(this.el).find('#login-anchor'));
+ this.element.hide($(this.el).find('#login-form'));
this.loadForm('reset');
this.element.scrollTop($('#password-reset-anchor'));
},
diff --git a/lms/static/sass/views/_support.scss b/lms/static/sass/views/_support.scss
index 829386c75c..2d94120d38 100644
--- a/lms/static/sass/views/_support.scss
+++ b/lms/static/sass/views/_support.scss
@@ -241,7 +241,7 @@
font-weight: $font-regular;
}
- .help-button {
+ .help-button, .btn-secondary {
margin-bottom: $baseline;
height: $baseline * 2;
font-weight: $font-regular;
diff --git a/lms/templates/student_account/access.underscore b/lms/templates/student_account/access.underscore
index 2f765aef1b..d52784e9c1 100644
--- a/lms/templates/student_account/access.underscore
+++ b/lms/templates/student_account/access.underscore
@@ -7,7 +7,7 @@
diff --git a/lms/static/js/spec/student_account/access_spec.js b/lms/static/js/spec/student_account/access_spec.js
index b592a79ade..5fd2a1b631 100644
--- a/lms/static/js/spec/student_account/access_spec.js
+++ b/lms/static/js/spec/student_account/access_spec.js
@@ -179,8 +179,8 @@
// Simulate a click on the reset password link
view.resetPassword();
- // Verify that the login-anchor is hidden
- expect($('#login-anchor')).toHaveClass('hidden');
+ // Verify that the login-form is hidden
+ expect($('#login-form')).toHaveClass('hidden');
// Verify that the password reset form is not hidden
expect($('#password-reset-form')).not.toHaveClass('hidden');